@@ -24,8 +24,6 @@
 # CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-__version__ = '0.2.1'
-
 import sys
 import os.path
 from optparse import OptionParser
@@ -41,6 +39,9 @@ else:
     from http import cookiejar
     from urllib import parse, request
 
+# Version Python-Acapela
+__version__ = '0.2.2'
+
 ACCOUNT_LOGIN = 'EVAL_XXXX'
 APPLICATION_LOGIN = 'EVAL_XXXXXXX'
 APPLICATION_PASSWORD = 'XXXXXXXX'
@@ -98,7 +99,7 @@ class Acapela(object):
         'FR': {'W': {'NORMAL': 'alice'}, 'M': {'NORMAL': 'antoine'}},
         'PT': {'W': {'NORMAL': 'celia'}},
         'BR': {'W': {'NORMAL': 'marcia'}},
-        }
+    }
 
     data = {}
     filename = None
@@ -130,13 +131,14 @@ class Acapela(object):
             'req_snd_id': key,
             'cl_login': self.ACCOUNT_LOGIN,
             'cl_vers': '1-30',
-            'req_err_as_id3': 'yes',
+            # req_err_as_id3 is depreciated
+            # 'req_err_as_id3': 'yes',
             'req_voice': req_voice,
             'cl_app': self.APPLICATION_LOGIN,
             'prot_vers': '2',
             'cl_pwd': self.APPLICATION_PASSWORD,
             'req_asw_type': 'STREAM',
-            }
+        }
         self.filename = '%s-%s.mp3' % (key, lang)
         self.data['req_text'] = '\\vct=100\\ \\spd=160\\ %s' \
             % text.encode('utf-8')
